@@ -8,7 +8,7 @@ extends 'API::Stripe::Client';
 use Carp ();
 use Scalar::Util ();
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 has identifier => (
     is       => 'rw',
@@ -124,7 +124,7 @@ API::Stripe - Perl 5 API wrapper for Stripe
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
@@ -132,15 +132,18 @@ version 0.01
 
     my $stripe = API::Stripe->new(
         username   => 'USERNAME',
-        identifier => 'APPLICATION (yourname@example.com)',
+        identifier => 'APPLICATION NAME',
     );
 
+    $stripe->debug(1);
+    $stripe->fatal(1);
+
     my $charge = $stripe->charges('ch_163Gh12CVMZwIkvc');
     my $results = $charge->fetch;
 
     # after some introspection
 
-    $charge->update;
+    $charge->update( ... );
 
 =head1 DESCRIPTION
 
@@ -163,22 +166,24 @@ returned.
 =head2 Building
 
     my $charge = $stripe->charges('ch_163Gh12CVMZwIkvc');
-    my $refunds = $charge->refunds;
 
-    $refunds->action; # GET /charges/ch_163Gh12CVMZwIkvc/refunds
-    $refunds->action('head'); # HEAD /charges/ch_163Gh12CVMZwIkvc/refunds
+    $charge->action; # GET /charges/ch_163Gh12CVMZwIkvc
+    $charge->action('head'); # HEAD /charges/ch_163Gh12CVMZwIkvc
+    $charge->action('patch'); # PATCH /charges/ch_163Gh12CVMZwIkvc
 
 Building up an HTTP request object is extremely easy, simply call method names
 which correspond to the API's path segments in the resource you wish to execute
 a request against. This module uses autoloading and returns a new instance with
 each method call. The following is the equivalent:
 
-    my $charge = $stripe->resource(charges => 'ch_163Gh12CVMZwIkvc');
-    my $refunds = $charge->resource('refunds');
+=head2 Chaining
+
+    my $refunds = $stripe->resource('charges', 'ch_163Gh12CVMZwIkvc', 'refunds');
 
     # or
 
-    my $refunds = $stripe->resource('charges', 'ch_163Gh12CVMZwIkvc', 'refunds');
+    my $charge = $stripe->charges('ch_163Gh12CVMZwIkvc');
+    my $refunds = $charge->refunds;
 
     # then
 
@@ -192,17 +197,15 @@ i.e., you will only need to configure the client once in your application.
 
     my $charges = $stripe->charges;
 
-    $charges->fetch(
-        query => {
-            # query-string parameters
-        },
-    );
+    # query-string parameters
+
+    $charges->fetch( query => { ... } );
 
     # equivalent to
 
-    $stripe->resource('charges')->action(
-        get => ( query => { ... } )
-    );
+    my $charges = $stripe->resource('charges');
+
+    $charges->action( get => ( query => { ... } ) );
 
 This example illustrates how you might fetch an API resource.
 
@@ -210,20 +213,13 @@ This example illustrates how you might fetch an API resource.
 
     my $charges = $stripe->charges;
 
-    $charges->create(
-        data => {
-            # content-body parameters
-        },
-        query => {
-            # query-string parameters
-        },
-    );
+    # content-body parameters
 
-    # or
+    $charges->create( data => { ... } );
 
-    my $charges = $stripe->charges;
+    # query-string parameters
 
-    $charges->create(...);
+    $charges->create( query => { ... } );
 
     # equivalent to
 
@@ -238,14 +234,13 @@ This example illustrates how you might create a new API resource.
     my $charges = $stripe->charges;
     my $charge  = $charges->resource('ch_163Gh12CVMZwIkvc');
 
-    $charge->update(
-        data => {
-            # content-body parameters
-        },
-        query => {
-            # query-string parameters
-        },
-    );
+    # content-body parameters
+
+    $charge->update( data => { ... } );
+
+    # query-string parameters
+
+    $charge->update( query => { ... } );
 
     # or
 
@@ -266,14 +261,13 @@ This example illustrates how you might update a new API resource.
     my $charges = $stripe->charges;
     my $charge  = $charges->resource('ch_163Gh12CVMZwIkvc');
 
-    $charge->delete(
-        data => {
-            # content-body parameters
-        },
-        query => {
-            # query-string parameters
-        },
-    );
+    # content-body parameters
+
+    $charge->delete( data => { ... } );
+
+    # query-string parameters
+
+    $charge->delete( query => { ... } );
 
     # or
 
@@ -293,12 +287,22 @@ This example illustrates how you might delete an API resource.
 
     my $charges = $stripe->resource('charges', 'ch_163Gh12CVMZwIkvc');
 
-    my ($results, $transaction) = $charges->fetch(...);
+    my ($results, $transaction) = $charges->action( ... );
 
-This example illustrates how you can access the transaction object used to
-submit the HTTP request.
+    my $request  = $transaction->req;
+    my $response = $transaction->res;
 
-=head1 PARAMETERS
+    my $headers;
+
+    $headers = $request->headers;
+    $headers = $response->headers;
+
+    # etc
+
+This example illustrates how you can access the transaction object used
+represent and process the HTTP transaction.
+
+=head1 ATTRIBUTES
 
 =head2 identifier
 
@@ -312,9 +316,7 @@ The identifier parameter should be set to a string that identifies your app.
     $stripe->username;
     $stripe->username('USERNAME');
 
-The username parameter should be set an API key associated with your account.
-
-=head1 ATTRIBUTES
+The username parameter should be set to an API key associated with your account.
 
 =head2 debug
 
@@ -337,7 +339,7 @@ exceptions, a L<API::Stripe::Exception> object.
     $stripe->retries(10);
 
 The retries attribute determines how many times an HTTP request should be
-retried if a 4xx or 5xx response is received. This attribute defaults to 1.
+retried if a 4xx or 5xx response is received. This attribute defaults to 0.
 
 =head2 timeout
 
@@ -435,180 +437,198 @@ included in the request if the key is either C<data> or C<query>.
     $stripe->account;
 
 The account method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#account>.
+I<Account> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#account>.
 
 =head2 application_fees
 
     $stripe->application_fees;
 
 The application_fees method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#application_fees>.
+I<Application Fees> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#application_fees>.
 
-=head2 balance-history
+=head2 balance
 
     $stripe->balance->history;
 
 The balance method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#balance>.
+I<Balance> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#balance>.
 
-=head2 bitcoin-receivers
+=head2 bitcoin_receivers
 
     $stripe->bitcoin->receivers;
 
-The bitcoin-receivers method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#bitcoin_receivers>.
+The bitcoin_receivers method returns a new instance representative of the API
+I<Bitcoin Receivers> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#bitcoin_receivers>.
 
 =head2 cards
 
     $stripe->cards;
 
 The cards method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#cards>.
+I<Cards> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#cards>.
 
 =head2 charges
 
     $stripe->charges;
 
 The charges method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#charges>.
+I<Charges> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#charges>.
 
 =head2 coupons
 
     $stripe->coupons;
 
 The coupons method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#coupons>.
+I<Coupons> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#coupons>.
 
 =head2 customers
 
     $stripe->customers;
 
 The customers method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#customers>.
+I<Customers> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#customers>.
 
 =head2 discounts
 
     $stripe->discounts;
 
 The discounts method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#discounts>.
+I<Discounts> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#discounts>.
 
 =head2 disputes
 
     $stripe->disputes;
 
 The disputes method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#disputes>.
+I<Disputes> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#disputes>.
 
 =head2 events
 
     $stripe->events;
 
 The events method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#events>.
+I<Events> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#events>.
 
-=head2 files
+=head2 fee_refunds
+
+    $stripe->application_fees('fee_6HiNDgLZ85q6KD')->refunds('fr_6HiNza7kmLzMFc');
+
+The fee_refunds method returns a new instance representative of the API
+I<Application Fee Refunds> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#fee_refunds>.
+
+=head2 file_uploads
 
     $stripe->files;
 
-The files method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#file_uploads>.
+The file_uploads method returns a new instance representative of the API
+I<File Uploads> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#file_uploads>.
 
 =head2 invoiceitems
 
     $stripe->invoiceitems;
 
 The invoiceitems method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#invoiceitems>.
+I<Invoice Items> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#invoiceitems>.
 
 =head2 invoices
 
     $stripe->invoices;
 
 The invoices method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#invoices>.
+I<Invoices> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#invoices>.
 
 =head2 plans
 
     $stripe->plans;
 
 The plans method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#plans>.
+I<Plans> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#plans>.
 
 =head2 recipients
 
     $stripe->recipients;
 
 The recipients method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#recipients>.
+I<Recipients> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#recipients>.
 
 =head2 refunds
 
     $stripe->refunds;
 
 The refunds method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#refunds>.
+I<Refunds> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#refunds>.
 
 =head2 subscriptions
 
     $stripe->subscriptions;
 
 The subscriptions method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#subscriptions>.
+I<Subscriptions> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#subscriptions>.
 
 =head2 tokens
 
     $stripe->tokens;
 
 The tokens method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#tokens>.
+I<Tokens> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#tokens>.
+
+=head2 transfer_reversals
+
+    $stripe->transfers('tr_164xRv2eZvKYlo2CZxJZWm1E')->reversals;
+
+The transfer_reversals method returns a new instance representative of the API
+I<Transfer Reversals> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#transfer_reversals>.
 
 =head2 transfers
 
     $stripe->transfers;
 
 The transfers method returns a new instance representative of the API
-resource requested. This method accepts a list of path segments which will be
-used in the HTTP request. The following documentation can be used to find more
-information. L<https://stripe.com/docs/api#transfers>.
+I<Transfers> resource requested. This method accepts a list of path
+segments which will be used in the HTTP request. The following documentation
+can be used to find more information. L<https://stripe.com/docs/api#transfers>.
 
 =head1 AUTHOR
 
